@@ -16,7 +16,6 @@
 import glob
 import hashlib
 import os
-import sqlite3
 import threading
 import time
 from io import BytesIO
@@ -26,6 +25,7 @@ from mapproxy.image import ImageSource
 from mapproxy.cache.base import TileCacheBase, tile_buffer, REMOVE_ON_UNLOCK
 from mapproxy.util.fs import ensure_directory
 from mapproxy.util.lock import FileLock
+from mapproxy.util.sqlite3 import sqlite3
 
 import logging
 log = logging.getLogger(__name__)
@@ -117,7 +117,7 @@ class MBTilesCache(TileCacheBase):
 
         if self.file_permissions:
             permission = int(self.file_permissions, base=8)
-            log.info("setting file permissions on MBTile file: ", permission)
+            log.info("setting file permissions on MBTile file: %s", permission)
             os.chmod(self.mbtile_file, permission)
 
     def update_metadata(self, name='', description='', version=1, overlay=True, format='png'):
@@ -272,7 +272,7 @@ class MBTilesCache(TileCacheBase):
 
         return loaded_tiles == len(tile_dict)
 
-    def remove_tile(self, tile):
+    def remove_tile(self, tile, dimensions=None):
         cursor = self.db.cursor()
         cursor.execute(
             "DELETE FROM tiles WHERE (tile_column = ? AND tile_row = ? AND zoom_level = ?)",
@@ -282,8 +282,8 @@ class MBTilesCache(TileCacheBase):
             return True
         return False
 
-    def remove_level_tiles_before(self, level, timestamp):
-        if timestamp == 0:
+    def remove_level_tiles_before(self, level, timestamp=None, remove_all=False):
+        if remove_all:
             cursor = self.db.cursor()
             cursor.execute(
                 "DELETE FROM tiles WHERE (zoom_level = ?)",
@@ -408,9 +408,9 @@ class MBTilesLevelCache(TileCacheBase):
     def load_tile_metadata(self, tile, dimensions=None):
         self.load_tile(tile, dimensions=dimensions)
 
-    def remove_level_tiles_before(self, level, timestamp):
+    def remove_level_tiles_before(self, level, timestamp=None, remove_all=False):
         level_cache = self._get_level(level)
-        if timestamp == 0:
+        if remove_all:
             level_cache.cleanup()
             os.unlink(level_cache.mbtile_file)
             for file in glob.glob("%s-*" % glob.escape(level_cache.mbtile_file)):
